==> v10.1.5.tar.gz: nativefier/.github/ISSUE_TEMPLATE/feature_request.md <==
---
name: Feature request
about: Suggest an idea for Nativefier
labels: feature-request

---

<!-- Help us help you, and take the time to fill this template 🙂.
An incomprehensible feature request is a useless feature request.

==============================================================
Incomprehensible / incomplete feature requests will be closed.
==============================================================
-->

**Homework**

- [ ] I looked at `nativefier --help` and https://github.com/jiahaog/nativefier/blob/master/docs/api.md , no existing option fits my needs.
- [ ] I searched existing issues, open & closed. Yes, my feature request is new.
- [ ] I'm using the latest version available at https://github.com/jiahaog/nativefier/releases


**Problem statement**

A clear and concise description of what the problem is. For example: *Nativefier should [...]. I need it because [...]. Existing options [...] are not exactly what I want, because [...]*

If related to a Nativefier config, provide your ***full*** nativefier command and its logs, with the ***`--verbose` flag***, on a ***public*** site:

```
nativefier --verbose --some-option https://mysite.com
<paste your verbose build logs, if relevant to your feature request>
```

**Suggested solution**

A clear and concise description of what you want to happen.


**Alternative solutions**

A clear and concise description of workarounds you've considered/tried.


**Context**

 - Nativefier: (for example: 9.1.0)
 - Node.js: (for example: 14.6.0)
 - Npm: (for example: 6.14.7)
 - OS: (for example: Windows 10 build 1809)
 - Additional context: (for example: "I'm behind a proxy, with configuration X and protocol Y")

==> v42.2.1.tar.gz: nativefier/.github/ISSUE_TEMPLATE/feature_request.md <==
---
name: Feature request
about: Suggest an idea for Nativefier
labels: feature-request

---

<!-- Help us help you, and take the time to fill this template 🙂.
An incomprehensible feature request is a useless feature request.

==============================================================
Incomprehensible / incomplete feature requests will be closed.
==============================================================
-->

**Homework**

- [ ] I looked at `nativefier --help` and https://github.com/nativefier/nativefier/blob/master/docs/api.md , no existing option fits my needs.
- [ ] I searched existing issues, open & closed. Yes, my feature request is new.
- [ ] I'm using the latest version available at https://github.com/nativefier/nativefier/releases


**Problem statement**

A clear and concise description of what the problem is. For example: *Nativefier should [...]. I need it because [...]. Existing options [...] are not exactly what I want, because [...]*

If related to a Nativefier config, provide your ***full*** nativefier command and its logs, with the ***`--verbose` flag***, on a ***public*** site:

```
nativefier --verbose --some-option https://mysite.com
<paste your verbose build logs, if relevant to your feature request>
```

**Suggested solution**

A clear and concise description of what you want to happen.


**Alternative solutions**

A clear and concise description of workarounds you've considered/tried.


**Context**

 - Nativefier: (for example: 9.1.0)
 - Node.js: (for example: 14.6.0)
 - Npm: (for example: 6.14.7)
 - OS: (for example: Windows 10 build 1809)
 - Additional context: (for example: "I'm behind a proxy, with configuration X and protocol Y")
